/*******************(C) COPYRIGHT 2022 Masses-Chip ******************************
*Project Name        : M8P615_ADC.prj
* File Name          : M8P615_ADC.C
* Author             : MASSES CHIP
* Version            : V1.03
* Date               : 2022/10/20
;* Web    			 : www.masses-chip.com
;* FAE               : Luo
;  				 	 : QQ：411680975
********************************************************************************
*
*Option:16T,WDT-Enable-288ms,BOR 2.4V 
*说明：本范例是输入通道AN0(IOA0)的AD(时钟FCPU 参考电压VDD)采集
连续采十次AD数据去掉最大最小值求平均得出AD值
******************************************************************************/
//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "ZC.h"
#include "MASSESCHIP_DEFINE.H"


//-------------------------------------------------------------------------------
//用户可以自行更改
void SYSTEM_INIT(void);					//系统初始化
void Clr_RAM_00H_3FH(void); 			//寄存器清零
void ADC_INIT(void);					//ADC初始化
void ADC_DATA_Real(void);				//ADC取值


//===============================================================================
//********************************程序主函数*************************************
//===============================================================================
void main(void)					  		//程序主函数
{
	SYSTEM_INIT();                  	//系统初始化
	Clr_RAM_00H_3FH();           	 	//清零RAM
	ADC_INIT();				   	  		//ADC初始化
	while(1) 
	{
		ADC_DATA_Real();
	}
}

//===============================================================================
//******************************中断服务子程序***********************************
//===============================================================================
void  Interrupt_Deal(void) __interrupt	
{
	__PUSH();							//进栈、保存A、STATUS
	
	__NOP();							
	
	__POP();                   			//出栈、恢复A、STATUS
}


//===============================================================================
//*********************************ADC初始化*************************************
//1、端口设置AN0(IOA0)口 输入模式 模拟口
//2、ADC设置 使能ADC 数据右对齐 输入通道AN0(IOA0) 
//ADC时钟FCPU 参考电压VDD
//===============================================================================
void ADC_INIT(void)
{
//1、端口设置
	OEA0 = 0;
	ANSA0 = 1;
//2、ADC设置
	ADCON0 = 0x90;
	ADCON1 = 0x00;
	ADCON2 = 0x00;
}

//===============================================================================
//**********************************系统初始化***********************************
//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
//IO初始化:设置个IO状态为输出低，且关闭上下拉
//中断总开关：关闭总开关
//===============================================================================	
void SYSTEM_INIT(void)
{ 
//----------------------------------------------------
//Init Clock
	OSCM = 0x00;
//----------------------------------------------------	            
//Init IO
	//IOA
	PUA = 0x00;                //0:上拉关闭 1:上拉使能
	IOA = 0x00;                //IO口数据
	OEA = 0xFF;                //0:输入 1:输出
	PDAB = 0x00;			   //0:下拉关闭 1:下拉使能
	//IOB
	PUB = 0x00;			   
	IOB = 0x00;                
	OEB = 0xFF; 
//----------------------------------------------------     
//Init Interrupt
	GIE = 0;                  //1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
}

//===============================================================================
//******************************RAM清零(00H_3FH)*****************************
//RAM清零：RAM区00H~3FH全部清零；
//===============================================================================
void Clr_RAM_00H_3FH(void)   
{
	for(FSR0 = 0;FSR0 < 0x40;FSR0++)
	{
		INDF0 = 0;
	}
}