/*******************(C) COPYRIGHT 2022 Masses-Chip ******************************
*Project Name        : M8P615_IOA5.prj
* File Name          : M8P615_IOA5.C
* Author             : MASSES CHIP
* Version            : V1.03
* Date               : 2022/10/20
;* Web    			 : www.masses-chip.com
;* FAE               : Luo
;  				 	 : QQ：411680975
********************************************************************************
*
*Option:16T,WDT-Enable-288ms,BOR 2.4V 
*说明：本范例是IOA5为中断源，IOA5变化中断唤醒休眠，反转IOB0
******************************************************************************/
//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "ZC.h"
#include "MASSESCHIP_DEFINE.H"


//-------------------------------------------------------------------------------
//用户可以自行更改
void SYSTEM_INIT(void);					//系统初始化
void Clr_RAM_00H_3FH(void); 			//寄存器清零
void IOA5_Interrupt_INIT(void);			//IOA5中断初始化
void IOA5_Interrupt_Deal(void);			//IOA5中断处理

ab8 Flag;
#define IOA5_Interrupt_Flag		Flag.oneBit.b0	//IOA5中断标志
//===============================================================================
//********************************程序主函数*************************************
//===============================================================================
void main(void)					  		//程序主函数
{
	SYSTEM_INIT();                  	//系统初始化
	Clr_RAM_00H_3FH();           	 	//清零RAM
	IOA5_Interrupt_INIT();				//IOA5中断初始化
	while(1) 
	{
		STOP = 1;
		if(IOA5_Interrupt_Flag == 1)
		{
			IOA5_Interrupt_Flag = 0;
			if(IOB0 == 1)
			{
				IOB0 = 0;
			}
			else
			{
				IOB0 = 1;
			}
		}
	}
}

//===============================================================================
//******************************中断服务子程序***********************************
//===============================================================================
void  Interrupt_Deal(void) __interrupt	
{
	__PUSH();							//进栈、保存A、STATUS
	
	IOA5_Interrupt_Deal();
	
	__POP();							//出栈、恢复A、STATUS
}

//===============================================================================
//******************************IOA5中断处理***********************************
//===============================================================================
void IOA5_Interrupt_Deal(void)
{
	if(IOCHIF == 1)
	{
		IOCHIF = 0;
		IOA5_Interrupt_Flag = 1;
	}
}

//===============================================================================
//*********************************IOA5初始化*************************************
//端口设置：IOA5输入模式，数字口，上拉开启
//IOA5中断设置：IOA5变化中断
//系统时钟设置：休眠状态下低频、高频振荡器停止工作
//===============================================================================
void IOA5_Interrupt_INIT(void)
{	
//1、端口设置
	OEA5 = 0;
	ANSA5 = 0;
	PUA5 = 1;
	
//2、IOA5中断设置
	IOA5ICR = 1;
	IOCHIE=1;
	IOCHIF=0;
	GIE = 1;
	
//3、系统时钟设置
	OSCM = 0x05;
}


//===============================================================================
//**********************************系统初始化***********************************
//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
//IO初始化:设置IO状态为输出低，且关闭上下拉
//中断总开关：关闭总开关
//===============================================================================	
void SYSTEM_INIT(void)
{ 
//----------------------------------------------------
//Init Clock
	OSCM = 0x00;
//----------------------------------------------------	            
//Init IO
	//IOA
	PUA = 0x00;                //0:上拉关闭 1:上拉使能
	IOA = 0x00;                //IO口数据
	OEA = 0xFF;                //0:输入 1:输出
	PDAB = 0x00;			   //0:下拉关闭 1:下拉使能
	//IOB
	PUB = 0x00;			   
	IOB = 0x00;                
	OEB = 0xFF; 
//----------------------------------------------------     
//Init Interrupt
	GIE = 0;                  //1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
}

//===============================================================================
//******************************RAM清零(00H_3FH)*****************************
//RAM清零：RAM区00H~3FH全部清零；
//===============================================================================
void Clr_RAM_00H_3FH(void)   
{
	for(FSR0 = 0;FSR0 < 0x40;FSR0++)
	{
		INDF0 = 0;
	}
}