;/*******************(ASM) COPYRIGHT 2022 Masses-Chip ******************************
;*Project Name        : M8P615_PWM0.prj
;* File Name          : M8P615_PWM0.ASM
;* Author             : MASSES CHIP
;* Version            : V1.03
;* Date               : 2022/10/20
;* Web    			  : www.masses-chip.com
;* FAE                : Luo
;  				 	  : QQ：411680975
;********************************************************************************
;*
;*Option:16T,WDT-Enable-288ms,BOR 2.4V 
;*说明：本范例以TC0为时基，PWM0(IOB0)输出1KHz波形，以100ms为周期开关PWM
;******************************************************************************/
;//===============================================================================
;//***********************************头文件**************************************
;//用户不可更改
;//===============================================================================
#INCLUDE	 	ZC.INC


;//===============================================================================
;//******************************定义全局变量*************************************
;//用户可以自行看需求定义变量
;//===============================================================================
userdata				udata	H'00'
Delay_Count_i			res		1						;//延时计数i
Delay_Count_j			res		1						;//延时计数j


;//===============================================================================
;//*********************************C O D E***************************************
;//===============================================================================	
		ORG			0000H
		GOTO		MainProgram
		ORG			0008H
		GOTO		Interrupt	

;//===============================================================================
;//********************************程序主函数*************************************
;//===============================================================================			
;//------------------------------程序初始化---------------------------------------
MainProgram:
		CALL       	SYSTEM_INIT				;//系统初始化
		CALL       	Clr_RAM_00H_3FH			;//清零RAM
		CALL       	PWM0_INIT				;//PWM0初始化
;//------------------------------主函数循环---------------------------------------		
MainLoop:
		CLRWDT	
		BSET		PWM0CR,6
		CALL		Delay_100ms
		BCLR		PWM0CR,6
		CALL		Delay_100ms
		GOTO		MainLoop
		
;//===============================================================================
;//******************************中断服务子程序***********************************
;//===============================================================================
;//中断进来	
Interrupt:
		PUSH
		NOP
Interrupt_END:	
;//中断结束
		POP
	    RETIE

;//===============================================================================
;//*********************************PWM0初始化*************************************
;//TC0设置：8位模式，高频系统时钟，1:64分频
;//PWM0设置：端口输出PWM,时基TC0
;//t =计数/（时钟/分频）     1ms = （249+1）/（16/64）
;//===============================================================================	
PWM0_INIT:
;//1、TC0设置
		MOVIA      	0x0E
		MOVAR	    T0CR		               		
		CLRR	   	TC0CH                    			
		MOVIA      	249
		MOVAR	   	TC0CL
;//2、PWM0设置
		MOVIA		0x80
		MOVAR		PWM0CR
		MOVIA		(249+1)/2
		MOVAR		PWM0D
		BSET       	T0CR,7			   	   					
		RETURN
		
;//===============================================================================
;//*********************************延时函数*************************************
;//延时100ms
;//===============================================================================		
Delay_100ms:
		NOP
		NOP
		NOP
		NOP
		NOP
		INCR		Delay_Count_j,1
		MOVIA		100
		JCMPAR		Delay_Count_j
		GOTO		Delay_100ms
		CLRR		Delay_Count_j
		INCR		Delay_Count_i,1
		MOVIA		100
		JCMPAR		Delay_Count_i
		GOTO		Delay_100ms
		CLRR		Delay_Count_i
		RETURN		

;//===============================================================================
;//**********************************系统初始化***********************************
;//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
;//IO初始化:设置IO状态为输出低，且关闭上下拉
;//中断总开关：关闭总开关
;//===============================================================================		
SYSTEM_INIT:
;//-----------------------------------------------------------------------           
;//Init Clock		
		MOVIA       b'00000000'
		MOVAR		OSCM
;//Init IO 
        ;//IOA
		MOVIA		0x00
        MOVAR     	PUA			;//0:上拉关闭 1:上拉使能
		MOVAR      	IOA        	;//0:输出低   1:输出高
		MOVAR		PDAB		;//0:下拉关闭 1:下拉使能
		MOVIA      	0xFF    	
        MOVAR      	OEA			;//0:输入     1:输出   	
		;//IOB
        MOVIA      	0x00		    	
        MOVAR      	PUB 	 	
        MOVAR      	IOB
		MOVIA      	0xFF    	
        MOVAR      	OEB
;//------------------------------------------------------------------------      
;//Init Interrupt          
        BCLR       	OPTION,7  		;//1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
		RETURN
		
;//===============================================================================
;//*****************************RAM清零(00H~3FH)******************************
;//RAM清零：RAM区00H~3FH全部清零；
;//===============================================================================				
Clr_RAM_00H_3FH:		
		CLRR		FSR0
Clr_RAM_00H_3FH_Loop:
		MOVIA		0x00
		MOVAR		INDF0
		INCR		FSR0,1
		JBTS1		FSR0,6
		GOTO		Clr_RAM_00H_3FH_Loop
		RETURN
		END
;//******************************END OF FILE*************************************       