/*******************(C) COPYRIGHT 2022 Masses-Chip ******************************
*Project Name        : M8P615_TC0.prj
* File Name          : M8P615_TC0.C
* Author             : MASSES CHIP
* Version            : V1.03
* Date               : 2022/10/20
;* Web    			 : www.masses-chip.com
;* FAE               : Luo
;  				 	 : QQ：411680975
********************************************************************************
*
*Option:16T,WDT-Enable-288ms,BOR 2.4V 
*说明：本范例以TC0为定时器，每定时1ms翻转一次IOB0口
******************************************************************************/
//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "ZC.h"
#include "MASSESCHIP_DEFINE.H"


//-------------------------------------------------------------------------------
//用户可以自行更改
void SYSTEM_INIT(void);					//系统初始化
void Clr_RAM_00H_3FH(void); 			//寄存器清零
void TC0_INIT(void);					//TC0初始化
void TC0_Interrupt (void);				//TC0中断处理函数

ab8 Flag;
#define	TC0_Interrupt_Flag	Flag.oneBit.b0 //TC0中断标志

//===============================================================================
//********************************程序主函数*************************************
//===============================================================================
void main(void)					  		//程序主函数
{
	SYSTEM_INIT();                  	//系统初始化
	Clr_RAM_00H_3FH();           	 	//清零RAM
	TC0_INIT();				   	  		//TC0初始化
	while(1) 
	{
		__CLRWDT();					  	//清除看门狗
		if(TC0_Interrupt_Flag == 1)
		{
			TC0_Interrupt_Flag = 0;
			if(IOB0 == 1)
			{
				IOB0 = 0;
			}
			else
			{
				IOB0 = 1;
			}
		}
	}
}

//===============================================================================
//******************************中断服务子程序***********************************
//===============================================================================
void  Interrupt_Deal(void) __interrupt	
{
	__PUSH();								//进栈、保存A、STATUS	
	
	TC0_Interrupt();							
	
	__POP();                   				//出栈、恢复A、STATUS
}

//===============================================================================
//******************************TC0中断处理函数**********************************
//===============================================================================
void TC0_Interrupt (void)				
{
	if(TC0IF)
	{					
		TC0IF = 0;
		TC0_Interrupt_Flag = 1;
	}
}


//===============================================================================
//*********************************TC0初始化*************************************
//TC0设置：8位模式，高频系统时钟，1:64分频
//t =计数/（时钟/分频）     1ms = （249+1）/（16/64）
//开启TC0溢出中断和总中断
//===============================================================================
void TC0_INIT(void)
{
//1、TC0设置
    T0CR =0x0E; 			
    TC0CH = 0;			
	TC0CL = 249;
//2、中断设置
	TC0IF = 0;
	TC0IE = 1;
	TC0EN = 1;								
	GIE = 1;				
}


//===============================================================================
//**********************************系统初始化***********************************
//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
//IO初始化:设置IO状态为输出低，且关闭上下拉
//中断总开关：关闭总开关
//===============================================================================	
void SYSTEM_INIT(void)
{ 
//----------------------------------------------------
//Init Clock
	OSCM = 0x00;
//----------------------------------------------------	            
//Init IO
	//IOA
	PUA = 0x00;                //0:上拉关闭 1:上拉使能
	IOA = 0x00;                //IO口数据
	OEA = 0xFF;                //0:输入 1:输出
	PDAB = 0x00;			   //0:下拉关闭 1:下拉使能
	//IOB
	PUB = 0x00;			   
	IOB = 0x00;                
	OEB = 0xFF; 
//----------------------------------------------------     
//Init Interrupt
	GIE = 0;                  //1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
}

//===============================================================================
//******************************RAM清零(00H_3FH)*****************************
//RAM清零：RAM区00H~3FH全部清零；
//===============================================================================
void Clr_RAM_00H_3FH(void)   
{
	for(FSR0 = 0;FSR0 < 0x40;FSR0++)
	{
		INDF0 = 0;
	}
}