/*******************(C) COPYRIGHT 2022 Masses-Chip ******************************
*Project Name        : M8P615_TC1.prj
* File Name          : M8P615_TC1.C
* Author             : MASSES CHIP
* Version            : V1.03
* Date               : 2022/10/20
;* Web    			 : www.masses-chip.com
;* FAE               : Luo
;  				 	 : QQ：411680975
********************************************************************************
*
*Option:16T,WDT-Enable-288ms,BOR 2.4V 
*说明：本范例以TC1为定时器，每定时1ms(由于自动TC1计数器无法自动重装,定时会有一
点点偏差)翻转一次IOB0口
******************************************************************************/
//===============================================================================
//*******************************头文件和调用申明********************************
//===============================================================================
//用户不可更改
#include "ZC.h"
#include "MASSESCHIP_DEFINE.H"


//-------------------------------------------------------------------------------
//用户可以自行更改
void SYSTEM_INIT(void);					//系统初始化
void Clr_RAM_00H_3FH(void); 			//寄存器清零
void TC1_INIT(void);					//TC1初始化
void TC1_Interrupt (void);				//TC1中断处理函数

ab8 Flag;
#define	TC1_Interrupt_Flag	Flag.oneBit.b0 //TC1中断标志

//===============================================================================
//********************************程序主函数*************************************
//===============================================================================
void main(void)					  		//程序主函数
{
	SYSTEM_INIT();                  	//系统初始化
	Clr_RAM_00H_3FH();           	 	//清零RAM
	TC1_INIT();				   	  		//TC1初始化
	while(1) 
	{
		__CLRWDT();					  	//清除看门狗
		if(TC1_Interrupt_Flag == 1)
		{
			TC1_Interrupt_Flag = 0;
			if(IOB0 == 1)
			{
				IOB0 = 0;
			}
			else
			{
				IOB0 = 1;
			}
		}
	}
}

//===============================================================================
//******************************中断服务子程序***********************************
//===============================================================================
void  Interrupt_Deal(void) __interrupt	
{
	__PUSH();							//进栈、保存A、STATUS

	TC1_Interrupt();
	
	__POP();                   			//出栈、恢复A、STATUS
}

//===============================================================================
//******************************TC1中断处理函数**********************************
//===============================================================================
void TC1_Interrupt (void)				
{
	if(TC1IF)
	{					
		TC1IF = 0;
		TC1CH = 0xFF;
		TC1CL = 0x05;
		TC1_Interrupt_Flag = 1;
	}
}


//===============================================================================
//*********************************TC1初始化*************************************
//TC1设置：16位模式，高频系统时钟，1:64分频
//t =计数/（时钟/分频）     1ms = （0xFFFF-FF05）/（16/64）
//开启TC1溢出中断和总中断
//===============================================================================
void TC1_INIT(void)
{
//1、TC1设置
    T1CR =0x4E;
    TC1CH = 0xFF;
	TC1CL = 0x05;
//2、中断设置
	TC1IF = 0;
	TC1IE = 1;
	TC1EN = 1;
	GIE = 1;				
}


//===============================================================================
//**********************************系统初始化***********************************
//系统时钟初始化：快钟、慢钟都正常工作，不进休眠
//IO初始化:设置IO状态为输出低，且关闭上下拉
//中断总开关：关闭总开关
//===============================================================================	
void SYSTEM_INIT(void)
{ 
//----------------------------------------------------
//Init Clock
	OSCM = 0x00;
//----------------------------------------------------	            
//Init IO
	//IOA
	PUA = 0x00;                //0:上拉关闭 1:上拉使能
	IOA = 0x00;                //IO口数据
	OEA = 0xFF;                //0:输入 1:输出
	PDAB = 0x00;			   //0:下拉关闭 1:下拉使能
	//IOB
	PUB = 0x00;			   
	IOB = 0x00;                
	OEB = 0xFF; 
//----------------------------------------------------     
//Init Interrupt
	GIE = 0;                  //1:全局中断高优先级中断使能,0:屏蔽全局中断高优先级中断
}

//===============================================================================
//******************************RAM清零(00H_3FH)*****************************
//RAM清零：RAM区00H~3FH全部清零；
//===============================================================================
void Clr_RAM_00H_3FH(void)   
{
	for(FSR0 = 0;FSR0 < 0x40;FSR0++)
	{
		INDF0 = 0;
	}
}